/*
 * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef __ZLTQTOPTIONVIEW_H__
#define __ZLTQTOPTIONVIEW_H__

#include <tqobject.h>

#include <ZLOptionsDialog.h>
#include <ZLOptionEntry.h>
#include "ZLOptionView.h"

class ZLTQtDialogContent;

class TQButtonGroup;
class TQLabel;
class TQSpinBox;
class TQCheckBox;
class TQListBox;
class TQLineEdit;
class TQPushButton;
class TQRadioButton;
class TQComboBox;
class TQSlider;
class TQWidget;

class ZLTQtOptionView : public ZLOptionView {

protected:
	ZLTQtOptionView(const std::string &name, const std::string &tooltip, ZLOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLOptionView(name, tooltip, option), myTab(tab), myRow(row), myFromColumn(fromColumn), myToColumn(toColumn) {}

protected:
	ZLTQtDialogContent *myTab;
	int myRow, myFromColumn, myToColumn;
};

class ChoiceOptionView : public ZLTQtOptionView {

public:
	ChoiceOptionView(const std::string &name, const std::string &tooltip, ZLChoiceOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn) {
		myButtons = 0;
	}
	~ChoiceOptionView() { if (myButtons != 0) delete[] myButtons; }

protected:
	void _createItem();
	void _show();
	void _hide();
	void _setActive(bool active);
	void _onAccept() const;

private:
	TQButtonGroup *myGroup;
	TQRadioButton **myButtons;
};

class BooleanOptionView : public TQObject, public ZLTQtOptionView {

TQ_OBJECT

public:
	BooleanOptionView(const std::string &name, const std::string &tooltip, ZLBooleanOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn) {}

protected:
	void _createItem();
	void _show();
	void _hide();
	void _setActive(bool active);
	void _onAccept() const;

private slots:
	void onStateChanged(bool) const;

private:
	TQCheckBox *myCheckBox;
};

class Boolean3OptionView : public TQObject, public ZLTQtOptionView {

TQ_OBJECT

public:
	Boolean3OptionView(const std::string &name, const std::string &tooltip, ZLBoolean3OptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn) {}

protected:
	void _createItem();
	void _show();
	void _hide();
	void _setActive(bool active);
	void _onAccept() const;

private slots:
	void onStateChanged(int) const;

private:
	TQCheckBox *myCheckBox;
};

class StringOptionView : public TQObject, public ZLTQtOptionView {

TQ_OBJECT

public:
	StringOptionView(const std::string &name, const std::string &tooltip, ZLStringOptionEntry *option, ZLTQtDialogContent *tab, bool passwordMode, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn), myLabel(0), myLineEdit(0), myPasswordMode(passwordMode) {}

private:
	void _createItem();
	void _show();
	void _hide();
	void _setActive(bool active);
	void _onAccept() const;
	void reset();

private slots:
	void onValueEdited(const TQString &value);

private:
	TQLabel *myLabel;
	TQLineEdit *myLineEdit;
	const bool myPasswordMode;
};

class SpinOptionView : public ZLTQtOptionView {

public:
	SpinOptionView(const std::string &name, const std::string &tooltip, ZLSpinOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn) {}

protected:
	void _createItem();
	void _show();
	void _hide();
	void _onAccept() const;

private:
	TQLabel *myLabel;
	TQSpinBox *mySpinBox;
};

class ComboOptionView : public TQObject, public ZLTQtOptionView {

TQ_OBJECT

public:
	ComboOptionView(const std::string &name, const std::string &tooltip, ZLComboOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn), myLabel(0), myComboBox(0) {}

private:
	void _createItem();
	void _show();
	void _hide();
	void _setActive(bool active);
	void _onAccept() const;
	void reset();

private slots:
	void onValueSelected(int index);
	void onValueEdited(const TQString &value);
	void onTabResized(const TQSize &size);
	
private:
	TQLabel *myLabel;
	TQComboBox *myComboBox;
};

class KeyOptionView : public TQObject, public ZLTQtOptionView {

TQ_OBJECT

public:
	KeyOptionView(const std::string &name, const std::string &tooltip, ZLKeyOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn), myWidget(0), myKeyEditor(0), myLabel(0), myComboBox(0) {}

private:
	void _createItem();
	void _show();
	void _hide();
	void _onAccept() const;
	void reset();

private slots:
	void onValueChanged(int);

private:
	TQWidget *myWidget;
	TQLineEdit *myKeyEditor;
	TQLabel *myLabel;
	TQComboBox *myComboBox;
	std::string myCurrentKey;

friend class KeyLineEdit;
};

class ColorOptionView : public TQObject, public ZLTQtOptionView {

TQ_OBJECT

public:
	ColorOptionView(const std::string &name, const std::string &tooltip, ZLColorOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn), myWidget(0), myRSlider(0), myGSlider(0), myBSlider(0), myColorBar(0) {}

private:
	void _createItem();
	void _show();
	void _hide();
	void _onAccept() const;
	void reset();

private slots:
	void onSliderMove(int);

private:
	TQWidget *myWidget;
	TQSlider *myRSlider, *myGSlider, *myBSlider;
	TQLabel *myColorBar;
};

class OrderOptionView : public TQObject, public ZLTQtOptionView {

TQ_OBJECT

public:
	OrderOptionView(const std::string &name, const std::string &tooltip, ZLOrderOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn) {}

protected:
	void _createItem();
	void _show();
	void _hide();
	void _onAccept() const;

private slots:
	void onChangeSelection();
	void onUpButtonPressed();
	void onDownButtonPressed();

private:
	TQWidget *myWidget;
	TQListBox *myListBox;
	TQPushButton *myUpButton, *myDownButton;
};

class StaticTextOptionView : public ZLTQtOptionView {

public:
	StaticTextOptionView(const std::string &name, const std::string &tooltip, ZLStaticTextOptionEntry *option, ZLTQtDialogContent *tab, int row, int fromColumn, int toColumn) : ZLTQtOptionView(name, tooltip, option, tab, row, fromColumn, toColumn), myLabel(0) {}

private:
	void _createItem();
	void _show();
	void _hide();
	void _onAccept() const;

private:
	TQLabel *myLabel;
};

#endif /* __ZLTQTOPTIONVIEW_H__ */
